@@ -41,6 +41,7 @@ from ...model import (
     RegisterOp,
     RegisterEvent,
     INFINITE_T,
+    LogSpace
 )
 
 ZP_EPS = 0.005
@@ -50,7 +51,7 @@ FREQ_EPS = 0.001
 # Global variables
 # ----------------
 
-log = logging.getLogger(__name__.split(".")[-1])
+log = logging.getLogger(LogSpace.DBASE)
 
 # ===================================
 # Registry process auxiliar functions
@@ -224,6 +225,7 @@ def renaming_photometer(
 def replacing_photometer(
     session: Session, old_mapping: NameMapping, candidate: PhotometerInfo, source: ReadingSource
 ) -> None:
+    plog = logging.getLogger(candidate.name)
     old_mapping.valid_until = candidate.tstamp
     old_mapping.valid_state = ValidState.EXPIRED
     session.add(old_mapping)
@@ -243,7 +245,8 @@ def replacing_photometer(
     another_tess = session.scalars(query).all()
     if another_tess:
         another_tess = another_tess[0]
-        log.warning("Replacing back %s", dict(candidate))
+        log.info("Replacing back %s", dict(candidate))
+        plog.debug("Replacing back %s", dict(candidate))
         updated = maybe_update_managed_attributes(session, candidate, another_tess)
         if updated:
             # self.nZPChange += 1
@@ -284,6 +287,7 @@ def replacing_photometer(
 
 
 def is_tess4c_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
+    plog = logging.getLogger(candidate.name)
     cand_zps = (candidate.zp1, candidate.zp2, candidate.zp3, candidate.zp4)
     phot_zps = (photometer.zp1, photometer.zp2, photometer.zp3, photometer.zp4)
     cand_off = (candidate.offset1, candidate.offset2, candidate.offset3, candidate.offset4)
@@ -302,6 +306,14 @@ def is_tess4c_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
             phot_zps,
             cand_zps,
         )
+        plog.debug(
+            "%s %s (%s) changing ZPs from %s to %s",
+            candidate.model,
+            candidate.name,
+            candidate.mac_address,
+            phot_zps,
+            cand_zps,
+        )
     if not unchanged_off:
         log.info(
             "%s %s (%s) changing Hz Offset from %s to %s",
@@ -311,6 +323,14 @@ def is_tess4c_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
             phot_off,
             cand_off,
         )
+        plog.debug(
+            "%s %s (%s) changing Hz Offset from %s to %s",
+            candidate.model,
+            candidate.name,
+            candidate.mac_address,
+            phot_off,
+            cand_off,
+        )
     if not unchanged_fil:
         log.info(
             "%s %s (%s) changing Filters from %s to %s",
@@ -320,10 +340,19 @@ def is_tess4c_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
             phot_fil,
             cand_fil,
         )
+        plog.debug(
+            "%s %s (%s) changing Filters from %s to %s",
+            candidate.model,
+            candidate.name,
+            candidate.mac_address,
+            phot_fil,
+            cand_fil,
+        )
     return not all([unchanged_zps, unchanged_off, unchanged_fil])
 
 
 def is_tessw_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
+    plog = logging.getLogger(candidate.name)
     cand_zps = (candidate.zp1,)
     phot_zps = (photometer.zp1,)
     cand_off = (candidate.offset1,)
@@ -339,6 +368,14 @@ def is_tessw_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
             phot_zps,
             cand_zps,
         )
+        plog.debug(
+            "%s %s (%s) changing ZP from %s to %s",
+            candidate.model,
+            candidate.name,
+            candidate.mac_address,
+            phot_zps,
+            cand_zps,
+        )
     if not unchanged_off:
         log.info(
             "%s %s (%s) changing Hz Offset from %s to %s",
@@ -348,6 +385,14 @@ def is_tessw_changed(photometer: Tess, candidate: PhotometerInfo) -> bool:
             phot_off,
             cand_off,
         )
+        plog.debug(
+            "%s %s (%s) changing Hz Offset from %s to %s",
+            candidate.model,
+            candidate.name,
+            candidate.mac_address,
+            phot_off,
+            cand_off,
+        )
     return not all([unchanged_zps, unchanged_off])
 
 
@@ -418,6 +463,7 @@ def photometer_register(
     source: ReadingSource = ReadingSource.DIRECT,
     dry_run: bool = False,
 ) -> None:
+    plog = logging.getLogger(candidate.name)
     old_mac_entry = lookup_mac(session, candidate.mac_address)
     old_name_entry = lookup_name(session, candidate.name)
 
@@ -433,6 +479,11 @@ def photometer_register(
             candidate.name,
             candidate.mac_address,
         )
+        plog.debug(
+            "Brand new photometer registered: %s (MAC = %s)",
+            candidate.name,
+            candidate.mac_address,
+        )
     elif old_mac_entry and not old_name_entry:
         # A clean rename with no collision
         # A (MAC, name) exists in the name_to_mac_t table with the MAC given by the candidate
@@ -447,6 +498,12 @@ def photometer_register(
             old_mac_entry.mac_address,
             candidate.name,
         )
+        plog.debug(
+            "Renamed photometer %s (MAC = %s) with brand new name %s",
+            old_mac_entry.name,
+            old_mac_entry.mac_address,
+            candidate.name,
+        )
     elif not old_mac_entry and old_name_entry:
         # Repairing a broken photometer
         # A (MAC, name) pair exist in the name_to_mac_t table with the same name as the candidate
@@ -462,6 +519,12 @@ def photometer_register(
             old_name_entry.mac_address,
             candidate.mac_address,
         )
+        plog.debug(
+            "Replaced photometer tagged %s (old MAC = %s) with new one with MAC %s",
+            old_name_entry.name,
+            old_name_entry.mac_address,
+            candidate.mac_address,
+        )
     else:
         # MAC not from the register message, but associtated to existing name
         # name not from from the register message, but assoctiated to to existing MAC
@@ -484,6 +547,11 @@ def photometer_register(
                     candidate.name,
                     candidate.mac_address,
                 )
+                plog.debug(
+                    "Detected reboot for photometer %s (MAC = %s)",
+                    candidate.name,
+                    candidate.mac_address,
+                )
         else:
             log.info(
                 "Overridden associations (%s -> %s) and (%s -> %s) with new (%s -> %s) association data",
@@ -494,12 +562,23 @@ def photometer_register(
                 candidate.name,
                 candidate.mac_address,
             )
-            log.warning("Label %s has no associated photometer now!", old_mac_entry.name)
+            plog.debug(
+                "Overridden associations (%s -> %s) and (%s -> %s) with new (%s -> %s) association data",
+                old_mac_entry.name,
+                old_mac_entry.mac_address,
+                old_name_entry.name,
+                old_name_entry.mac_address,
+                candidate.name,
+                candidate.mac_address,
+            )
+            log.info("Label %s has no associated photometer now!", old_mac_entry.name)
+            plog.debug("Label %s has no associated photometer now!", old_mac_entry.name)
             override_associations(session, old_mac_entry, old_name_entry, candidate)
             pub.sendMessage(RegisterOp.EXTINCT, source=source)
 
     if dry_run:
-        log.warning("Dry run mode. Database not written")
+        log.info("Dry run mode. Database not written")
+        plog.debug("Dry run mode. Database not written")
         session.rollback()
 
 
@@ -514,9 +593,11 @@ def photometer_assign(
     update_readings_until: Optional[datetime] = None,
     dry_run: bool = False,
 ) -> None:
+    plog = logging.getLogger(phot_name)
     photometer = find_photometer_by_name(session, phot_name)
     if not photometer:
         log.error("Photometer not found => %s", phot_name)
+        plog.debug("Photometer not found => %s", phot_name)
         return
     old_observer_id = photometer.observer_id
     old_location_id = photometer.location_id
@@ -531,8 +612,17 @@ def photometer_assign(
         location_id,
         observer_id,
     )
+    plog.debug(
+        "Assigning to tess_id = %d with previous location_id = %d and observer_id = %d new location_id = %d and new observer_id = %d",
+        photometer.tess_id,
+        old_location_id,
+        old_observer_id,
+        location_id,
+        observer_id,
+    )
     if all([old_observer_id == observer_id, old_location_id == location_id]):
         log.info("No change in location_id nor observer_id. nothing to do.")
+        plog.debug("No change in location_id nor observer_id. nothing to do.")
         return
     photometer.observer_id = observer_id
     photometer.location_id = location_id
@@ -576,6 +666,7 @@ def photometer_assign(
             )
         N = session.scalars(query).one()
         log.info("This will affect %d rows", N)
+        plog.info("This will affect %d rows", N)
     if dry_run:
         log.warning("Dry run mode. Database not written")
         session.rollback()
